aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2012-09-11 11:42:53 +0000
committerstuconnolly <stuart02@gmail.com>2012-09-11 11:42:53 +0000
commit4c4d1fe137e6fb56ebc0c962c7aaa0a926d81722 (patch)
tree2cb1638ff30e41d8b4c0bd676ab8e984c150626f
parentab9c87af48c8831a5bbd4b924e9200df92a78e0e (diff)
downloadsequelpro-4c4d1fe137e6fb56ebc0c962c7aaa0a926d81722.tar.gz
sequelpro-4c4d1fe137e6fb56ebc0c962c7aaa0a926d81722.tar.bz2
sequelpro-4c4d1fe137e6fb56ebc0c962c7aaa0a926d81722.zip
Update libpq built from PostgreSQL 9.2 source.
-rw-r--r--Frameworks/PostgresKit/Libs/libpq/include/libpq-fe.h29
-rw-r--r--Frameworks/PostgresKit/Libs/libpq/lib/libpq.abin687820 -> 712660 bytes
2 files changed, 16 insertions, 13 deletions
diff --git a/Frameworks/PostgresKit/Libs/libpq/lib/libpq.a b/Frameworks/PostgresKit/Libs/libpq/lib/libpq.a
index 72502f0c..6f4fd1b4 100644
--- a/Frameworks/PostgresKit/Libs/libpq/lib/libpq.a
+++ b/Frameworks/PostgresKit/Libs/libpq/lib/libpq.a
Binary files differ
diff --git a/Frameworks/PostgresKit/Libs/libpq/include/libpq-fe.h b/Frameworks/PostgresKit/Libs/libpq/include/libpq-fe.h
index d7802753..9d05dd20 100644
--- a/Frameworks/PostgresKit/Libs/libpq/include/libpq-fe.h
+++ b/Frameworks/PostgresKit/Libs/libpq/include/libpq-fe.h
@@ -4,7 +4,7 @@
* This file contains definitions for structures and
* externs for functions used by frontend postgres applications.
*
- * Portions Copyright (c) 1996-2011, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2012, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
* src/interfaces/libpq/libpq-fe.h
@@ -38,13 +38,14 @@ extern "C"
/* Application-visible enum types */
+/*
+ * Although it is okay to add to these lists, values which become unused
+ * should never be removed, nor should constants be redefined - that would
+ * break compatibility with existing code.
+ */
+
typedef enum
{
- /*
- * Although it is okay to add to this list, values which become unused
- * should never be removed, nor should constants be redefined - that would
- * break compatibility with existing code.
- */
CONNECTION_OK,
CONNECTION_BAD,
/* Non-blocking mode only below here */
@@ -89,7 +90,8 @@ typedef enum
* backend */
PGRES_NONFATAL_ERROR, /* notice or warning message */
PGRES_FATAL_ERROR, /* query failed */
- PGRES_COPY_BOTH /* Copy In/Out data transfer in progress */
+ PGRES_COPY_BOTH, /* Copy In/Out data transfer in progress */
+ PGRES_SINGLE_TUPLE /* single tuple from larger resultset */
} ExecStatusType;
typedef enum
@@ -235,14 +237,14 @@ typedef struct pgresAttDesc
/* make a new client connection to the backend */
/* Asynchronous (non-blocking) */
extern PGconn *PQconnectStart(const char *conninfo);
-extern PGconn *PQconnectStartParams(const char **keywords,
- const char **values, int expand_dbname);
+extern PGconn *PQconnectStartParams(const char *const * keywords,
+ const char *const * values, int expand_dbname);
extern PostgresPollingStatusType PQconnectPoll(PGconn *conn);
/* Synchronous (blocking) */
extern PGconn *PQconnectdb(const char *conninfo);
-extern PGconn *PQconnectdbParams(const char **keywords,
- const char **values, int expand_dbname);
+extern PGconn *PQconnectdbParams(const char *const * keywords,
+ const char *const * values, int expand_dbname);
extern PGconn *PQsetdbLogin(const char *pghost, const char *pgport,
const char *pgoptions, const char *pgtty,
const char *dbName,
@@ -387,6 +389,7 @@ extern int PQsendQueryPrepared(PGconn *conn,
const int *paramLengths,
const int *paramFormats,
int resultFormat);
+extern int PQsetSingleRowMode(PGconn *conn);
extern PGresult *PQgetResult(PGconn *conn);
/* Routines for managing an asynchronous query */
@@ -413,8 +416,8 @@ extern int PQsetnonblocking(PGconn *conn, int arg);
extern int PQisnonblocking(const PGconn *conn);
extern int PQisthreadsafe(void);
extern PGPing PQping(const char *conninfo);
-extern PGPing PQpingParams(const char **keywords,
- const char **values, int expand_dbname);
+extern PGPing PQpingParams(const char *const * keywords,
+ const char *const * values, int expand_dbname);
/* Force the write buffer to be written (or at least try) */
extern int PQflush(PGconn *conn);